@@ -349,7 +349,14 @@ up_device_to_text (UpDevice *device)
 			g_string_append_printf (string, "    voltage-min-design:  %g V\n", up_exported_device_get_voltage_min_design (priv->proxy_device));
 		if (up_exported_device_get_voltage_max_design (priv->proxy_device) > 0)
 			g_string_append_printf (string, "    voltage-max-design:  %g V\n", up_exported_device_get_voltage_max_design (priv->proxy_device));
+
+		/* Eliminate the display of the deprecation warning specific to the CapacityLevel property. */
+		/* DEPRECATED. This property is deprecated since it is duplicated from the 'BatteryLevel' property. */
+		#pragma GCC diagnostic push
+		#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 		capacity_level = up_exported_device_get_capacity_level (priv->proxy_device);
+		#pragma GCC diagnostic pop
+
 		if (capacity_level != NULL && capacity_level[0] != '\0')
 			g_string_append_printf (string, "    capacity-level:      %s\n", capacity_level);
 	}
@@ -369,8 +376,12 @@ up_device_to_text (UpDevice *device)
 			g_string_append_printf (string, "    charge-cycles:       %s\n", "N/A");
 	}
 	if (kind == UP_DEVICE_KIND_KEYBOARD) {
+		/* DEPRECATED. This property is deprecated since the code it depends on was removed in 0.99.12. */
+		#pragma GCC diagnostic push
+		#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 		if (up_exported_device_get_luminosity (priv->proxy_device) > 0)
 			g_string_append_printf (string, "    luminosity:          %g lx\n", up_exported_device_get_luminosity (priv->proxy_device));
+		#pragma GCC diagnostic pop
 	}
 	if (kind == UP_DEVICE_KIND_BATTERY ||
 	    kind == UP_DEVICE_KIND_UPS) {
@@ -419,6 +430,7 @@ up_device_to_text (UpDevice *device)
 	if (up_exported_device_get_has_history (priv->proxy_device)) {
 		up_device_to_text_history (device, string, "charge");
 		up_device_to_text_history (device, string, "rate");
+		up_device_to_text_history (device, string, "voltage");
 	}
 
 	return g_string_free (string, FALSE);
@@ -450,7 +462,7 @@ up_device_refresh_sync (UpDevice *device, GCancellable *cancellable, GError **er
 /**
  * up_device_get_history_sync:
  * @device: a #UpDevice instance.
- * @type: The type of history, known values are "rate" and "charge".
+ * @type: The type of history. Known values are "rate", "charge" and "voltage".
  * @timespec: the amount of time to look back into time.
  * @resolution: the resolution of data.
  * @cancellable: a #GCancellable or %NULL
@@ -686,7 +698,11 @@ up_device_set_property (GObject *object, guint prop_id, const GValue *value, GPa
 		up_exported_device_set_voltage (device->priv->proxy_device, g_value_get_double (value));
 		break;
 	case PROP_LUMINOSITY:
+		/* DEPRECATED. This property is deprecated since the code it depends on was removed in 0.99.12. */
+		#pragma GCC diagnostic push
+		#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 		up_exported_device_set_luminosity (device->priv->proxy_device, g_value_get_double (value));
+		#pragma GCC diagnostic pop
 		break;
 	case PROP_TIME_TO_EMPTY:
 		up_exported_device_set_time_to_empty (device->priv->proxy_device, g_value_get_int64 (value));
@@ -733,9 +749,14 @@ up_device_set_property (GObject *object, guint prop_id, const GValue *value, GPa
 	case PROP_VOLTAGE_MAX_DESIGN:
 		up_exported_device_set_voltage_max_design (device->priv->proxy_device, g_value_get_double (value));
 		break;
+	/* Eliminate the display of the deprecation warning specific to the CapacityLevel property. */
+	/* DEPRECATED. This property is deprecated since it is duplicated from the 'BatteryLevel' property. */
+	#pragma GCC diagnostic push
+	#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 	case PROP_CAPACITY_LEVEL:
 		up_exported_device_set_capacity_level (device->priv->proxy_device, g_value_get_string (value));
 		break;
+	#pragma GCC diagnostic pop
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -827,7 +848,11 @@ up_device_get_property (GObject *object, guint prop_id, GValue *value, GParamSpe
 		g_value_set_double (value, up_exported_device_get_voltage (device->priv->proxy_device));
 		break;
 	case PROP_LUMINOSITY:
+		/* DEPRECATED. This property is deprecated since the code it depends on was removed in 0.99.12. */
+		#pragma GCC diagnostic push
+		#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 		g_value_set_double (value, up_exported_device_get_luminosity (device->priv->proxy_device));
+		#pragma GCC diagnostic pop
 		break;
 	case PROP_TIME_TO_EMPTY:
 		g_value_set_int64 (value, up_exported_device_get_time_to_empty (device->priv->proxy_device));
@@ -871,9 +896,14 @@ up_device_get_property (GObject *object, guint prop_id, GValue *value, GParamSpe
 	case PROP_VOLTAGE_MAX_DESIGN:
 		g_value_set_double (value, up_exported_device_get_voltage_max_design (device->priv->proxy_device));
 		break;
+	/* Eliminate the display of the deprecation warning specific to the CapacityLevel property. */
+	/* DEPRECATED. This property is deprecated since it is duplicated from the 'BatteryLevel' property. */
+	#pragma GCC diagnostic push
+	#pragma GCC diagnostic ignored "-Wdeprecated-declarations"
 	case PROP_CAPACITY_LEVEL:
 		g_value_set_string (value, up_exported_device_get_capacity_level (device->priv->proxy_device));
 		break;
+	#pragma GCC diagnostic pop
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -1173,13 +1203,16 @@ up_device_class_init (UpDeviceClass *klass)
 	 *
 	 * The current luminosity of the device.
 	 *
+	 * NOTE: As of 1.91.1, this property is deprecated since the code it
+	 * depends on was removed in 0.99.12.
+	 *
 	 * Since: 0.9.19
 	 **/
 	g_object_class_install_property (object_class,
 					 PROP_LUMINOSITY,
 					 g_param_spec_double ("luminosity", NULL, NULL,
 							      0.0, G_MAXDOUBLE, 0.0,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_DEPRECATED));
 	/**
 	 * UpDevice:time-to-empty:
 	 *
@@ -1381,12 +1414,15 @@ up_device_class_init (UpDeviceClass *klass)
 	 * Unknown, Critical, Low, Normal, High, and Full.
 	 *
 	 * Since: 1.90.10
+	 *
+	 * DEPRECATED.
+	 * This property is deprecated since it is duplicated from the 'BatteryLevel' property.
 	 **/
 	g_object_class_install_property (object_class,
 					 PROP_CAPACITY_LEVEL,
 					 g_param_spec_string ("capacity-level",
 							      NULL, NULL, NULL,
-							      G_PARAM_READWRITE));
+							      G_PARAM_READWRITE | G_PARAM_DEPRECATED));
 }
 
 static void
